"""get 命令"""

import typer
import json
from ..core.models import Idea
from ..db import get_connection
from dong import json_output, NotFoundError
from rich.console import Console

console = Console()

@json_output
def get(
    idea_id: int = typer.Argument(..., help="想法 ID"),
):
    """获取想法详情

    Args:
        idea_id: 想法 ID    """
    conn = get_connection()
    cursor = conn.cursor()
    cursor.execute("SELECT * FROM ideas WHERE id = ?", (idea_id,))
    row = cursor.fetchone()
    conn.close()

    if not row:
        raise NotFoundError("Idea", idea_id, message=f"未找到 ID 为 {idea_id} 的想法")

    idea = Idea.from_row(row)
    return idea.to_dict()


if __name__ == "__main__":
    get()



"""CLI 入口"""

import typer
from rich.console import Console
from dong import json_output
from . import const

console = Console()

app = typer.Typer(
    name="dong-think",
    help="思咚咚 - 记录灵感和想法",
    no_args_is_help=True,
    add_completion=False,
)


def version_callback(value: bool) -> None:
    """版本号回调函数"""
    if value:
        console.print(f"dong-think {const.VERSION}")
        raise typer.Exit()


@app.callback()
def global_options(
    version: bool = typer.Option(
        False,
        "--version",
        "-v",
        help="显示版本号",
        callback=version_callback,
        is_eager=True,
    ),
) -> None:
    """全局选项"""
    pass


@app.command()
@json_output
def init():
    """初始化数据库"""
    from .commands import init
    return init.init()


@app.command()
@json_output
def add(
    content: str = typer.Argument(..., help="想法内容"),
    tag: str = typer.Option(None, "--tag", "-t", help="标签"),
    priority: str = typer.Option("normal", "--priority", "-p", help="优先级"),
    context: str = typer.Option(None, "--context", "-c", help="上下文"),
):
    """记录想法"""
    from .commands import add
    return add.add(content=content, tag=tag, priority=priority, context=context)


@app.command()
@json_output
def list(
    limit: int = typer.Option(20, "--limit", "-l", help="返回数量"),
    tag: str = typer.Option(None, "--tag", "-t", help="按标签筛选"),
):
    """列出想法"""
    from .commands import ls
    return ls.list_ideas(limit=limit, tag=tag)


@app.command()
@json_output
def get(
    idea_id: int = typer.Argument(..., help="想法 ID"),
):
    """获取想法详情"""
    from .commands import get
    return get.get(idea_id=idea_id)


@app.command()
@json_output
def delete(
    idea_id: int = typer.Argument(..., help="想法 ID"),
):
    """删除想法"""
    from .commands import delete
    return delete.delete(idea_id=idea_id)


@app.command()
@json_output
def search(
    keyword: str = typer.Argument(..., help="搜索关键词"),
    limit: int = typer.Option(20, "--limit", "-l", help="返回数量"),
):
    """搜索想法"""
    from .commands import search
    return search.search(keyword=keyword, limit=limit)


@app.command()
@json_output
def update(
    idea_id: int = typer.Argument(..., help="想法 ID"),
    content: str = typer.Option(None, "--content", "-c", help="更新内容"),
    tag: str = typer.Option(None, "--tag", "-t", help="标签"),
):
    """更新想法"""
    from .commands import update
    return update.update(idea_id=idea_id, content=content, tag=tag)


@app.command()
@json_output
def review():
    """回顾想法"""
    from .commands import review
    return review.review()


@app.command()
@json_output
def stats():
    """统计信息"""
    from .commands import stats
    return stats.stats()


@app.command()
@json_output
def tags():
    """列出所有标签"""
    from .commands import tags
    return tags.tags()


@app.command()
def export(
    output: str = typer.Option("think.json", "-o", "--output", help="输出文件"),
    format: str = typer.Option("json", "-f", "--format", help="格式: json"),
):
    """导出数据"""
    from .commands import export as do_export
    do_export(output, format)


@app.command(name="import")
def import_data(
    file: str = typer.Option(..., "-f", "--file", help="导入文件"),
    merge: bool = typer.Option(False, "--merge", help="合并模式"),
    dry_run: bool = typer.Option(False, "--dry-run", help="预览模式"),
):
    """导入数据"""
    from .commands import data_import
    return data_import.import_data(file=file, merge=merge, dry_run=dry_run)


if __name__ == "__main__":
    app()



"""数据模型"""

from typing import Optional, List, Dict, Any
from datetime import datetime
from ..const import PRIORITIES, STATUSES


class Idea:
    """想法模型"""

    def __init__(
        self,
        id: Optional[int] = None,
        content: str = "",
        tags: Optional[List[str]] = None,
        priority: str = "normal",
        status: str = "idea",
        context: Optional[str] = None,
        source_agent: Optional[str] = None,
        note: Optional[str] = None,
        created_at: Optional[str] = None,
        updated_at: Optional[str] = None,
    ):
        self.id = id
        self.content = content
        self.tags = tags or []
        self.priority = priority
        self.status = status
        self.context = context
        self.source_agent = source_agent
        self.note = note
        self.created_at = created_at
        self.updated_at = updated_at

    @classmethod
    def from_row(cls, row) -> "Idea":
        """从数据库行创建实例"""
        tags = None
        if row["tags"]:
            import json
            tags = json.loads(row["tags"])

        return cls(
            id=row["id"],
            content=row["content"],
            tags=tags,
            priority=row["priority"],
            status=row["status"],
            context=row["context"],
            source_agent=row["source_agent"],
            note=row["note"],
            created_at=row["created_at"],
            updated_at=row["updated_at"],
        )

    def to_dict(self) -> Dict[str, Any]:
        """转换为字典"""
        import json
        return {
            "id": self.id,
            "content": self.content,
            "tags": self.tags,
            "priority": self.priority,
            "status": self.status,
            "context": self.context,
            "source_agent": self.source_agent,
            "note": self.note,
            "created_at": self.created_at,
            "updated_at": self.updated_at,
        }

    @classmethod
    def from_dict(cls, data: Dict[str, Any]) -> "Idea":
        """从字典创建实例"""
        return cls(**data)

    def validate(self) -> bool:
        """验证数据"""
        if not self.content or not self.content.strip():
            return False
        if self.priority not in PRIORITIES:
            self.priority = PRIORITY_NORMAL
        if self.status not in STATUSES:
            self.status = STATUS_IDEA
        return True



"""review 命令"""

import typer
import json
from datetime import datetime, timedelta
from ..core.models import Idea
from ..db import get_connection
from ..const import STATUSES, PRIORITIES, APP_NAME
from rich.console import Console
from rich.panel import Panel

console = Console()


def review(
    today: bool = typer.Option(False, "--today", help="只显示今天的想法"),
    week: bool = typer.Option(False, "--week", help="只显示本周的想法"),
    random: bool = typer.Option(False, "--random", help="随机显示一条想法"),
):
    """回顾想法

    Args:
        today: 只显示今天的想法
        week: 只显示本周的想法
        random: 随机显示一条想法
    """
    conn = get_connection()
    cursor = conn.cursor()

    query = "SELECT * FROM ideas ORDER BY RANDOM() LIMIT 1"
    params = []

    if today:
        today_str = datetime.now().strftime("%Y-%m-%d")
        query = "SELECT * FROM ideas WHERE date(created_at) = ? ORDER BY RANDOM() LIMIT 1"
        params = [today_str]
    elif week:
        week_ago = (datetime.now() - timedelta(days=7)).strftime("%Y-%m-%d")
        query = "SELECT * FROM ideas WHERE date(created_at) >= ? ORDER BY RANDOM() LIMIT 1"
        params = [week_ago]

    cursor.execute(query, params)
    row = cursor.fetchone()
    conn.close()

    if not row:
        if today:
            console.print(f"[yellow]{APP_NAME} 今天还没有想法记录[/yellow]")
        elif week:
            console.print(f"[yellow]{APP_NAME} 本周还没有想法记录[/yellow]")
        else:
            console.print(f"[yellow]{APP_NAME} 还没有想法记录，快去记一条吧！💡[/yellow]")
        return

    idea = Idea.from_row(row)

    # 使用 Rich 显示
    console.print(Panel(
        f"{idea.content}\n\n[italic]#{idea.id} | {idea.created_at.split('T')[0]}[/italic]",
        title="💡 思考时间",
        title_align="left",
    ))

    if idea.tags:
        tags_str = ", ".join(idea.tags)
        console.print(f"[dim]标签: {tags_str}[/dim]")

    console.print(f"[dim]上下文: {idea.context or '无'}[/dim]")


if __name__ == "__main__":
    review()



"""初始化命令"""

import typer
from rich.console import Console
from pathlib import Path
from ..db import init_database
from ..const import APP_NAME, VERSION, DATA_DIR

console = Console()

def init(
    db_path: Path = None,
    yes: bool = typer.Option(False, "--yes", "-y", help="不提示，直接初始化"),
):
    """初始化数据库

    Args:
        db_path: 数据库文件路径，默认使用 ~/.think/think.db
        yes: 不提示，直接初始化
    """
    if db_path is None:
        db_path = DATA_DIR / "think.db"

    # 检查是否已存在
    if db_path.exists():
        if not yes:
            confirm = typer.confirm(
                f"{db_path} 已存在，是否覆盖？",
                default=False,
            )
            if not confirm:
                console.print("[yellow]已取消初始化[/yellow]")
                return

    try:
        init_database(db_path)
        console.print(f"[green]✅ {APP_NAME} 初始化成功[/green]")
        console.print(f"    数据库路径: {db_path}")
        console.print(f"    版本: v{VERSION}")
    except Exception as e:
        console.print(f"[red]❌ 初始化失败: {e}[/red]")
        raise typer.Exit(code=1)



"""tags 命令 - 列出所有标签及数量"""

import typer
import json
from collections import Counter
from ..db import get_connection
from rich.console import Console

console = Console()


def tags(
    json_output: bool = typer.Option(False, "--json", help="JSON 输出"),
):
    """列出所有标签及使用数量

    Args:
        json_output: JSON 输出
    """
    conn = get_connection()
    cursor = conn.cursor()

    cursor.execute("SELECT tags FROM ideas WHERE tags IS NOT NULL AND tags != ''")
    rows = cursor.fetchall()
    conn.close()

    # 统计标签
    tag_counter = Counter()
    for row in rows:
        try:
            tags_list = json.loads(row["tags"])
            if tags_list:
                tag_counter.update(tags_list)
        except (json.JSONDecodeError, TypeError):
            continue

    # 构建结果
    tags_list = [{"tag": tag, "count": count} for tag, count in tag_counter.most_common()]

    result = {
        "success": True,
        "data": {
            "total_tags": len(tag_counter),
            "total_usages": sum(tag_counter.values()),
            "tags": tags_list
        }
    }

    if json_output:
        console.print(json.dumps(result, ensure_ascii=False, indent=2))
        return

    # 美化输出
    if not tags_list:
        console.print("[yellow]暂无标签[/yellow]")
        return

    from rich.table import Table
    table = Table(show_header=True, header_style="bold cyan")
    table.add_column("标签", style="green")
    table.add_column("数量", justify="right")

    for item in tags_list:
        table.add_row(item["tag"], str(item["count"]))

    console.print(table)
    console.print(f"\n总计: {len(tag_counter)} 个标签, {sum(tag_counter.values())} 次使用")


if __name__ == "__main__":
    tags()



"""delete 命令"""

import typer
import json
from ..core.models import Idea
from ..db import get_connection
from dong import json_output, NotFoundError
from rich.console import Console

console = Console()

@json_output
def delete(
    idea_id: int = typer.Argument(..., help="想法 ID"),
    force: bool = typer.Option(False, "--force", "-f", help="强制删除，不提示"),
):
    """删除想法

    Args:
        idea_id: 想法 ID
        force: 强制删除，不提示
    """
    conn = get_connection()
    cursor = conn.cursor()
    cursor.execute("SELECT * FROM ideas WHERE id = ?", (idea_id,))
    row = cursor.fetchone()

    if not row:
        conn.close()
        raise NotFoundError("Idea", idea_id, message=f"未找到 ID 为 {idea_id} 的想法")

    idea = Idea.from_row(row)

    if not force:
        confirm = typer.confirm(f"确定要删除想法吗？\n{idea.content}")
        if not confirm:
            conn.close()
            return {"cancelled": True, "message": "已取消删除"}

    cursor.execute("DELETE FROM ideas WHERE id = ?", (idea_id,))
    conn.commit()
    conn.close()

    return {"deleted": True, "id": idea_id}


if __name__ == "__main__":
    delete()



"""ls 命令"""

import typer
import json
from datetime import datetime
from ..core.models import Idea
from ..db import get_connection
from ..const import DEFAULT_LIMIT, PRIORITIES, STATUSES
from rich.console import Console
from rich.table import Table
from rich.panel import Panel

console = Console()


def _is_option_info(value):
    """检查是否是 Typer OptionInfo 对象"""
    return hasattr(value, '__class__') and value.__class__.__name__ == 'OptionInfo'


def list_ideas(
    limit: int = typer.Option(DEFAULT_LIMIT, "--limit", "-l", help="显示数量"),
    today: bool = typer.Option(False, "--today", help="只显示今天的"),
    week: bool = typer.Option(False, "--week", help="只显示本周的"),
    tag: str = typer.Option(None, "--tag", help="按标签筛选"),
    priority: str = typer.Option(None, "--priority", help="按优先级筛选: low/normal/high"),
    status: str = typer.Option(None, "--status", help="按状态筛选"),
    json_output: bool = typer.Option(False, "--json", help="JSON 输出"),
):
    """列出想法

    Args:
        limit: 显示数量
        today: 只显示今天的
        week: 只显示本周的
        tag: 按标签筛选
        priority: 按优先级筛选
        status: 按状态筛选
        json_output: JSON 输出
    """
    # 过滤 OptionInfo 对象
    if _is_option_info(priority):
        priority = None
    if _is_option_info(status):
        status = None

    conn = get_connection()
    cursor = conn.cursor()

    # 构建查询条件
    conditions = []
    params = []

    if today:
        today_str = datetime.now().strftime("%Y-%m-%d")
        conditions.append("date(created_at) = ?")
        params.append(today_str)

    if week:
        from datetime import timedelta
        week_ago = (datetime.now() - timedelta(days=7)).strftime("%Y-%m-%d")
        conditions.append("date(created_at) >= ?")
        params.append(week_ago)

    if tag:
        conditions.append("tags LIKE ?")
        params.append(f"%{tag}%")

    if priority:
        if priority not in PRIORITIES:
            console.print(f"[yellow]⚠️  无效的优先级: {priority}[/yellow]")
            priority = None
        else:
            conditions.append("priority = ?")
            params.append(priority)

    if status:
        if status not in STATUSES:
            console.print(f"[yellow]⚠️  无效的状态: {status}[/yellow]")
            status = None
        else:
            conditions.append("status = ?")
            params.append(status)

    where_clause = " AND ".join(conditions) if conditions else "1=1"
    params.extend([limit, 0])  # limit 和 offset

    query = f"""
        SELECT * FROM ideas
        WHERE {where_clause}
        ORDER BY created_at DESC
        LIMIT ? OFFSET ?
    """

    cursor.execute(query, params)
    rows = cursor.fetchall()

    if json_output:
        ideas = [Idea.from_row(row).to_dict() for row in rows]
        console.print(json.dumps(ideas, ensure_ascii=False, indent=2))
        return

    if not rows:
        console.print("[yellow]没有想法记录[/yellow]")
        return

    # 创建表格
    table = Table(show_header=True, header_style="bold magenta")
    table.add_column("ID", style="dim", width=6)
    table.add_column("内容", width=40)
    table.add_column("标签", width=20)
    table.add_column("优先级", width=10)
    table.add_column("状态", width=10)
    table.add_column("时间", style="dim")

    for row in rows:
        idea = Idea.from_row(row)
        tags_str = ", ".join(idea.tags) if idea.tags else ""
        time_str = idea.created_at.split("T")[0] if idea.created_at else ""

        # 根据优先级设置颜色
        priority_style = {
            "high": "bold red",
            "normal": "bold white",
            "low": "yellow",
        }.get(idea.priority, "")

        # 根据状态设置颜色
        status_style = {
            "done": "green",
            "doing": "cyan",
            "todo": "yellow",
            "idea": "dim",
        }.get(idea.status, "")

        table.add_row(
            str(idea.id),
            idea.content[:40] + "..." if len(idea.content) > 40 else idea.content,
            tags_str[:20],
            f"[{priority_style}]{idea.priority}[/{priority_style}]" if priority_style else idea.priority,
            f"[{status_style}]{idea.status}[/{status_style}]" if status_style else idea.status,
            time_str,
        )

    # 统计信息（使用同一个连接）
    total = conn.execute("SELECT COUNT(*) FROM ideas").fetchone()[0]
    console.print(f"\n总计: {total} 条想法")

    conn.close()


if __name__ == "__main__":
    list_ideas()



"""数据库 Schema 定义和版本管理

继承 dong.db.SchemaManager，管理 think-cli 的数据库 schema。
"""

from dong.db import SchemaManager
from .connection import ThinkDatabase

SCHEMA_VERSION = "1.0.0"


class ThinkSchemaManager(SchemaManager):
    """思咚咚 Schema 管理器"""

    def __init__(self):
        super().__init__(
            db_class=ThinkDatabase,
            current_version=SCHEMA_VERSION
        )

    def init_schema(self) -> None:
        self._create_thoughts_table()
        self._create_indexes()

    def _create_thoughts_table(self) -> None:
        with ThinkDatabase.get_cursor() as cur:
            cur.execute("""
                CREATE TABLE IF NOT EXISTS thoughts (
                    id INTEGER PRIMARY KEY AUTOINCREMENT,
                    content TEXT NOT NULL,
                    tags TEXT,
                    created_at TEXT DEFAULT CURRENT_TIMESTAMP,
                    updated_at TEXT DEFAULT CURRENT_TIMESTAMP
                )
            """)

    def _create_indexes(self) -> None:
        with ThinkDatabase.get_cursor() as cur:
            cur.execute("CREATE INDEX IF NOT EXISTS idx_thoughts_tags ON thoughts(tags)")


# 兼容性函数
def get_schema_version() -> str | None:
    return ThinkSchemaManager().get_stored_version()

def set_schema_version(version: str) -> None:
    ThinkDatabase.set_meta(ThinkSchemaManager.VERSION_KEY, version)

def is_initialized() -> bool:
    return ThinkSchemaManager().is_initialized()

def init_database() -> None:
    schema = ThinkSchemaManager()
    if not schema.is_initialized():
        schema.initialize()



"""search 命令"""

import typer
import json
from ..core.models import Idea
from ..db import get_connection
from ..const import PRIORITIES, STATUSES
from rich.console import Console
from rich.table import Table

console = Console()


def search(
    keyword: str = typer.Argument(..., help="搜索关键词"),
    tag: str = typer.Option(None, "--tag", help="按标签筛选"),
    priority: str = typer.Option(None, "--priority", help="按优先级筛选: low/normal/high"),
    status: str = typer.Option(None, "--status", help="按状态筛选"),
    json_output: bool = typer.Option(False, "--json", help="JSON 输出"),
):
    """搜索想法

    Args:
        keyword: 搜索关键词
        tag: 按标签筛选
        priority: 按优先级筛选
        status: 按状态筛选
        json_output: JSON 输出
    """
    conn = get_connection()
    cursor = conn.cursor()

    # 构建查询条件
    conditions = ["content LIKE ?"]  # 关键词搜索
    params = [f"%{keyword}%"]

    if tag:
        conditions.append("tags LIKE ?")
        params.append(f"%{tag}%")

    if priority:
        if priority not in PRIORITIES:
            console.print(f"[yellow]⚠️  无效的优先级: {priority}[/yellow]")
        else:
            conditions.append("priority = ?")
            params.append(priority)

    if status:
        if status not in STATUSES:
            console.print(f"[yellow]⚠️  无效的状态: {status}[/yellow]")
        else:
            conditions.append("status = ?")
            params.append(status)

    where_clause = " AND ".join(conditions) if conditions else "1=1"

    query = f"""
        SELECT * FROM ideas
        WHERE {where_clause}
        ORDER BY created_at DESC
    """

    cursor.execute(query, params)
    rows = cursor.fetchall()
    conn.close()

    if json_output:
        ideas = [Idea.from_row(row).to_dict() for row in rows]
        console.print(json.dumps(ideas, ensure_ascii=False, indent=2))
        return

    if not rows:
        console.print(f"[yellow]未找到包含 '{keyword}' 的想法[/yellow]")
        return

    # 创建表格
    table = Table(show_header=True, header_style="bold magenta")
    table.add_column("ID", style="dim", width=6)
    table.add_column("内容", width=40)
    table.add_column("标签", width=20)
    table.add_column("时间", style="dim")

    for row in rows:
        idea = Idea.from_row(row)
        tags_str = ", ".join(idea.tags) if idea.tags else ""
        time_str = idea.created_at.split("T")[0] if idea.created_at else ""

        table.add_row(
            str(idea.id),
            idea.content[:40] + "..." if len(idea.content) > 40 else idea.content,
            tags_str[:20],
            time_str,
        )

    console.print(table)
    console.print(f"[dim]找到 {len(rows)} 条结果[/dim]")


if __name__ == "__main__":
    search()



"""导出器模块"""
from typing import Any
from dong.io import BaseExporter, ExporterRegistry
from .db.connection import ThinkDatabase

class ThinkExporter(BaseExporter):
    name = "think"
    
    def fetch_all(self) -> list[dict[str, Any]]:
        with ThinkDatabase.get_cursor() as cur:
            cur.execute("""
                SELECT id, content, tags, priority, status, context, 
                       source_agent, note, created_at, updated_at
                FROM ideas ORDER BY created_at DESC
            """)
            return [
                {
                    "id": row[0], "content": row[1], "tags": row[2].split(",") if row[2] else [],
                    "priority": row[3], "status": row[4], "context": row[5],
                    "source_agent": row[6], "note": row[7],
                    "created_at": row[8], "updated_at": row[9],
                }
                for row in cur.fetchall()
            ]

ExporterRegistry.register(ThinkExporter())



"""stats 命令"""

import json
from datetime import datetime, timedelta
from ..core.models import Idea
from ..db import get_connection
from ..const import APP_NAME, PRIORITIES, STATUSES
from rich.console import Console
from rich.table import Table
from rich.progress import Progress

console = Console()


def stats():
    """统计想法信息"""
    conn = get_connection()
    cursor = conn.cursor()

    # 总数
    cursor.execute("SELECT COUNT(*) FROM ideas")
    total = cursor.fetchone()[0]

    # 按状态统计
    cursor.execute("""
        SELECT status, COUNT(*) as count
        FROM ideas
        GROUP BY status
    """)
    status_stats = {row["status"]: row["count"] for row in cursor.fetchall()}

    # 按优先级统计
    cursor.execute("""
        SELECT priority, COUNT(*) as count
        FROM ideas
        GROUP BY priority
    """)
    priority_stats = {row["priority"]: row["count"] for row in cursor.fetchall()}

    # 最近7天
    week_ago = (datetime.now() - timedelta(days=7)).strftime("%Y-%m-%d")
    cursor.execute("SELECT COUNT(*) FROM ideas WHERE date(created_at) >= ?", [week_ago])
    this_week = cursor.fetchone()[0]

    # 最近30天
    month_ago = (datetime.now() - timedelta(days=30)).strftime("%Y-%m-%d")
    cursor.execute("SELECT COUNT(*) FROM ideas WHERE date(created_at) >= ?", [month_ago])
    this_month = cursor.fetchone()[0]

    conn.close()

    # 显示统计表
    table = Table(title=f"📊 {APP_NAME} 统计", show_header=True, header_style="bold magenta")
    table.add_column("指标", style="cyan")
    table.add_column("数值", style="bold green")

    table.add_row("总想法数", str(total))
    table.add_row("本周新增", str(this_week))
    table.add_row("本月新增", str(this_month))
    table.add_row("", "")

    # 状态统计
    for status in STATUSES:
        count = status_stats.get(status, 0)
        if count > 0:
            table.add_row(f"  - {status}", str(count))

    table.add_row("", "")

    # 优先级统计
    for priority in PRIORITIES:
        count = priority_stats.get(priority, 0)
        if count > 0:
            table.add_row(f"  - {priority}", str(count))

    console.print(table)

    # 显示建议
    if total == 0:
        console.print(f"\n💡 提示: 还没有想法记录，快去记一条吧！")
    elif this_week == 0:
        console.print(f"\n💡 提示: 本周还没有想法记录，快去记一条吧！")
    else:
        console.print(f"\n💡 提示: 记录想法，让你的思考有迹可循！")


if __name__ == "__main__":
    stats()



"""update 命令"""

import typer
import json
from ..core.models import Idea
from ..db import get_connection
from ..const import PRIORITIES, STATUSES
from rich.console import Console

console = Console()


def update(
    idea_id: int = typer.Argument(..., help="想法 ID"),
    status: str = typer.Option(None, "--status", help="更新状态"),
    priority: str = typer.Option(None, "--priority", help="更新优先级: low/normal/high"),
    tag_add: str = typer.Option(None, "--add-tag", help="添加标签"),
    tag_remove: str = typer.Option(None, "--remove-tag", help="移除标签"),
    note: str = typer.Option(None, "--note", help="更新备注"),
):
    """更新想法

    Args:
        idea_id: 想法 ID
        status: 更新状态
        priority: 更新优先级
        tag_add: 添加标签
        tag_remove: 移除标签
        note: 更新备注
    """
    conn = get_connection()
    cursor = conn.cursor()

    # 获取当前想法
    cursor.execute("SELECT * FROM ideas WHERE id = ?", (idea_id,))
    row = cursor.fetchone()

    if not row:
        console.print(f"[red]❌ 未找到 ID 为 {idea_id} 的想法[/red]")
        conn.close()
        raise typer.Exit(code=1)

    idea = Idea.from_row(row)

    # 解析当前标签
    current_tags = idea.tags or []

    # 更新状态
    if status:
        if status not in STATUSES:
            console.print(f"[yellow]⚠️  无效的状态: {status}[/yellow]")
        else:
            idea.status = status

    # 更新优先级
    if priority:
        if priority not in PRIORITIES:
            console.print(f"[yellow]⚠️  无效的优先级: {priority}[/yellow]")
        else:
            idea.priority = priority

    # 添加标签
    if tag_add:
        new_tag = tag_add.strip()
        if new_tag and new_tag not in current_tags:
            current_tags.append(new_tag)
            idea.tags = current_tags

    # 移除标签
    if tag_remove:
        tag_to_remove = tag_remove.strip()
        if tag_to_remove in current_tags:
            current_tags.remove(tag_to_remove)
            idea.tags = current_tags if current_tags else None

    # 更新备注
    if note is not None:
        idea.note = note

    # 更新数据库
    cursor.execute(
        """
        UPDATE ideas
        SET tags = ?, priority = ?, status = ?, note = ?, updated_at = ?
        WHERE id = ?
        """,
        (
            json.dumps(current_tags) if current_tags else None,
            idea.priority,
            idea.status,
            idea.note,
            idea.updated_at,  # 会重新赋值
            idea_id,
        ),
    )
    conn.commit()
    conn.close()

    console.print(f"[green]✅ 已更新想法 #{idea_id}[/green]")
    if idea.status:
        console.print(f"    状态: {idea.status}")
    if idea.priority:
        console.print(f"    优先级: {idea.priority}")


if __name__ == "__main__":
    update()



"""常量定义"""

VERSION = "0.7.5"
APP_NAME = "思咚咚"

# 数据目录 - 统一放在 ~/.dong/ 下
from pathlib import Path
DATA_DIR = Path.home() / ".dong" / "think"
DB_PATH = DATA_DIR / "think.db"

# 默认值
DEFAULT_LIMIT = 20

# 优先级
PRIORITY_LOW = "low"
PRIORITY_NORMAL = "normal"
PRIORITY_HIGH = "high"
PRIORITIES = [PRIORITY_LOW, PRIORITY_NORMAL, PRIORITY_HIGH]

# 状态
STATUS_IDEA = "idea"
STATUS_TODO = "todo"
STATUS_DOING = "doing"
STATUS_DONE = "done"
STATUSES = [STATUS_IDEA, STATUS_TODO, STATUS_DOING, STATUS_DONE]



"""配置管理模块

继承 dong.config.Config，管理 think-cli 的用户配置。
"""

from dong.config import Config


class ThinkConfig(Config):
    """思咚咚配置类"""

    @classmethod
    def get_name(cls) -> str:
        return "think"

    @classmethod
    def get_defaults(cls) -> dict:
        return {
            "default_tags": ["idea", "insight"],
            "default_limit": 20,
        }


# 便捷函数
def get_config() -> dict:
    return ThinkConfig.load()

def get_default_tags() -> list:
    return ThinkConfig.get("default_tags", ["idea", "insight"])

def get_default_limit() -> int:
    return ThinkConfig.get("default_limit", 20)



"""add 命令"""

import typer
import json
from datetime import datetime
from pathlib import Path
from ..core.models import Idea
from ..db import get_connection
from ..const import PRIORITIES, STATUSES
from dong import json_output, ValidationError
from rich.console import Console
from rich.table import Table

console = Console()


def _is_option_info(value):
    """检查是否是 Typer OptionInfo 对象"""
    return hasattr(value, '__class__') and value.__class__.__name__ == 'OptionInfo'


@json_output
def add(
    content: str = typer.Argument(..., help="想法内容"),
    tag: str = typer.Option(None, "--tag", "-t", help="标签，多个用逗号分隔"),
    priority: str = typer.Option("normal", "--priority", "-p",
                                   help="优先级: low/normal/high"),
    context: str = typer.Option(None, "--context", "-c", help="上下文"),
    source_agent: str = typer.Option(None, "--source", "-s", help="来源智能体"),
    note: str = typer.Option(None, "--note", "-n", help="备注"),
):
    """记录想法"""
    if not content or not content.strip():
        raise ValidationError("content", "想法内容不能为空")

    # 过滤 OptionInfo 对象，使用默认值
    if _is_option_info(priority):
        priority = "normal"
    if _is_option_info(context):
        context = None
    if _is_option_info(source_agent):
        source_agent = None
    if _is_option_info(note):
        note = None

    conn = get_connection()

    # 处理标签
    tags = []
    if tag:
        tags = [t.strip() for t in tag.split(",") if t.strip()]

    # 创建想法
    idea = Idea(
        content=content.strip(),
        tags=tags if tags else None,
        priority=priority,
        context=context,
        source_agent=source_agent,
        note=note,
    )

    # 插入数据库
    cursor = conn.cursor()
    cursor.execute(
        """
        INSERT INTO ideas (content, tags, priority, context, source_agent, note, created_at, updated_at)
        VALUES (?, ?, ?, ?, ?, ?, ?, ?)
        """,
        (
            idea.content,
            json.dumps(idea.tags) if idea.tags else None,
            idea.priority,
            idea.context,
            idea.source_agent,
            idea.note,
            datetime.now().isoformat(),
            datetime.now().isoformat(),
        ),
    )
    conn.commit()

    idea_id = cursor.lastrowid
    conn.close()

    idea.id = idea_id
    return idea.to_dict()
